CLI Reference — PyMedPhys

Toggle navigation sidebar
Toggle in-page Table of Contents

# CLI Reference

This section displays the help text for each of PyMedPhys’ CLI commands. Help test is sturctured as follows:

    usage: pymedphys [-h] [-v] [-d] {dicom,experimental,trf,dev,zenodo,icom,gui,streamlit} ...

## Named Arguments

`-v, --verbose`

  Be verbose

  Default: False

`-d, --debug`

  Print debugging statements

  Default: False

This presents what to write into the command prompt to use that CLI command.

- DICOM Files
- Elekta Binary Logfiles
- iCom listener
- Pinnacle Export Tool
- Pseudonymisation Tool